        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 17 <strong>control</strong><br>0,1,3,11,15,19,20,21,25,27,28,29,32,33,43,48,49';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <br>4,5,10,12,13,14,24,26,31,40,41,44,46';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 8 <br>6,9,16,30,36,37,38,50';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>34</strong> miembros: 7 <br>8,18,34,35,39,45,47';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260613 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>23</strong> miembros: 6 <br>2,7,17,22,23,42';}
}
